/**
 * @file
 * Contains javascript functionality for the draggable blocks module.
 */

(function ($, window, Drupal) {

  'use strict';

  Drupal.draggableDashboard = Drupal.draggableDashboard || {};

  Drupal.draggableDashboard.dashboardChanged = function ($dashboard) {
    var blocks = {};
    $dashboard.find('.draggable-dashboard-column').each(function () {
      var columnId = '#' + $(this).attr('id');
      // Build blocks object
      if (typeof blocks[columnId] === 'undefined') {
        blocks[columnId] = [];
      }
      $(this).find('.draggable-dashboard-block').each(function (i, e) {
        var blockId = '#' + $(this).attr('id');
        blocks[columnId].push(blockId);
      });
    });

    localStorage.setItem('dashboard-blocks-order', JSON.stringify(blocks));
  };

  Drupal.behaviors.draggable_dashboard = {
    attach: function (context, settings) {
      $('.draggable-dashboard', context).once('dashboard-processed').each(function () {
        var $dashboards = $('.draggable-dashboard', context);
        var blocks = {};
        // If we already saved an order in the local storage, get the value
        if (localStorage.getItem('dashboard-blocks-order')) {
          blocks = JSON.parse(localStorage.getItem('dashboard-blocks-order'));
        }

        $dashboards.each(function () {
          var $dashboard = $(this);
          $(this).find('div.draggable-dashboard-column').each(function() {
            // Make columns sortable
            Sortable.create(document.getElementById($(this).attr('id')), {
              draggable: '.draggable-dashboard-block',
              handle: '.draggable-dashboard-block__header',
              onEnd: function () {
                Drupal.draggableDashboard.dashboardChanged($dashboard);
              }
            });
          })
        });

        // Rearrange blocks.
        if (blocks !== 'undefined') {
          $.each(blocks, function (col, blocksInCol) {
            // Put every block in the correct place in its region.
            $.each(blocksInCol, function (j, block) {
              $(col).append($(block));
            });
          });
        }

      });
    }
  };

})(jQuery, window, Drupal);
